@@ -50,6 +50,8 @@ class Bolide():
 		:param show_plot bool (optional): bool for showing plot with visual elements, default True
 		:param outfile str (outfile): outfile where the bounding box image will be saved, default None which uses the eventid
 		:return float: cloudiness in the bounding box between 0 and 1, where 0 is no cloud and 1 is all cloud
+
+		NOTE: the NOAA AWS S3 buckets only have CSM data after December of 2019
 		"""
 		cloudiness = []
 		for glm in self.detectedBy:
@@ -73,4 +75,30 @@ class Bolide():
 			goes = glm.split("-")[-1]
 			get_bb_image(goes, self.eventid, self.latitude, self.longitude, self.datetime, 
 				image_type=image_type, bsize_degrees=bsize_degrees, ref_grid_resolution_km=ref_grid_resolution_km, 
-				show_plot=show_plot, outfile=outfile)
\ No newline at end of file
+				show_plot=show_plot, outfile=outfile)
+
+
+class UnlistedPotentialBolideEvent(Bolide):
+	"""Represents a potential bright fireball NOT yet reported at https://neo-bolide.ndc.nasa.gov
+	Parameters
+	----------
+	eventid : str
+			Unique identifier of the event, could just be some filler.
+	detectedBy : str
+			The GOES satellite(s) that detected the event ("16" or "17" or "16,17").
+	lat : float
+			Latitude of the potential bolide event.
+	lon : float
+			Longitude of the potential bolide event.
+	datetime : str
+			Timestamp of the potential bolide event (example format "2020-07-31T18:05:05.0Z")
+	"""
+	def __init__(self, eventid, detectedBy, lat, lon, datetime):
+		self.eventid = eventid
+		self.json = {
+			"detectedBy": detectedBy,
+			"latitude": lat,
+			"longitude": lon,
+			"datetime": datetime
+		}
+		self.nSatellites = len(detectedBy)
\ No newline at end of file
